@@ -397,7 +397,7 @@ void decompress(Reader* in, Writer* out);
 // Encoder compresses using an arithmetic code
 class Encoder {
 public:
-  Encoder(ZPAQL& z, int size=0):
+  Encoder(ZPAQL& z):
     out(0), low(1), high(0xFFFFFFFF), pr(z) {}
   void init();
   void compress(int c);  // c is 0..255 or EOF
@@ -449,7 +449,7 @@ void compress(Reader* in, Writer* out, int level);
 #define unlikely(x)	__builtin_expect(!!(x), 0)
 #define __maybe_unused	__attribute__((unused))
 
-typedef long long int i64;
+typedef int64_t i64;
 
 struct bufRead: public libzpaq::Reader {
 	uchar *s_buf;
